pub struct PointerState {
pub pos: Option<[f32; 2]>,
pub buttons: Vec<Button>,
pub modifiers: Modifiers,
}Expand description
The pointer as reported to callers.
Fields
pos: Option<[f32; 2]>Position in egui points, null when the pointer is not over the surface.
modifiers: ModifiersTrait Implementations
Sourceimpl Clone for PointerState
impl Clone for PointerState
Sourcefn clone(&self) -> PointerState
fn clone(&self) -> PointerState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PointerState
impl Debug for PointerState
Sourceimpl JsonSchema for PointerState
impl JsonSchema for PointerState
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PointerState
impl RefUnwindSafe for PointerState
impl Send for PointerState
impl Sync for PointerState
impl Unpin for PointerState
impl UnsafeUnpin for PointerState
impl UnwindSafe for PointerState