pub fn try_init() -> Result<(), SetLoggerError>Expand description
Install the logger. Mirrors env_logger::try_init: Err if some other
logger is already installed, and the caller is free to ignore that.
pub fn try_init() -> Result<(), SetLoggerError>Install the logger. Mirrors env_logger::try_init: Err if some other
logger is already installed, and the caller is free to ignore that.