DockContext

Struct DockContext 

pub struct DockContext<'a> {
    pub docs: &'a mut Documents,
    pub viewport: &'a mut Viewport,
    pub history: &'a mut HistoryPanel,
    pub bom: &'a mut BomPanel,
    pub assembly_constraints: &'a mut AssemblyConstraintsPanel,
    pub wire_harness: &'a mut WireHarnessPanel,
    pub pmi: &'a mut PmiPanel,
    pub scene: &'a mut ScenePanel,
    pub expressions: &'a mut ExpressionsPanel,
    pub update_components: &'a mut UpdateComponents,
    pub model_store: &'a dyn ModelStore,
}
The disjoint &mut borrows the dock needs to draw a frame — assembled by the shell from BrepApp’s fields (all distinct, so the borrow checker allows it).

Fields

docs: &'a mut Documents

The open documents. The dock reaches the ACTIVE engine through docs.engine_mut() — a borrow of one FIELD, so it still composes with the disjoint panel borrows beside it (see crate::document).

viewport: &'a mut Viewporthistory: &'a mut HistoryPanelbom: &'a mut BomPanelassembly_constraints: &'a mut AssemblyConstraintsPanelwire_harness: &'a mut WireHarnessPanelpmi: &'a mut PmiPanelscene: &'a mut ScenePanelexpressions: &'a mut ExpressionsPanelupdate_components: &'a mut UpdateComponentsmodel_store: &'a dyn ModelStore